# -*- coding: utf-8 -*-
# flake8: noqa
# pylint: skip-file
from ._bnf import query

__version__ = '1.0.2'

__plugin_author__ = 'xlcnd'
__plugin_description__ = 'Metadata for French books from catalogue.bnf.fr'
__plugin_homepage__ = 'github.com/xlcnd/isbnlib-bnf'
__plugin_service_language__ = 'fr'
__plugin_service_name__ = 'bnf'
__plugin_type__ = 'metadata'
